==> snapchat_flutter_plugin-0.0.2%2B1.tar.gz: android/src/main/java/com/proflutterdev/snapchat_flutter_plugin/SnapchatFlutterPlugin.java <==
package com.proflutterdev.snapchat_flutter_plugin;

import android.app.Activity;
import android.support.annotation.Nullable;

import com.snapchat.kit.sdk.SnapLogin;
import com.snapchat.kit.sdk.core.controller.LoginStateController;
import com.snapchat.kit.sdk.login.models.MeData;
import com.snapchat.kit.sdk.login.models.UserDataResponse;
import com.snapchat.kit.sdk.login.networking.FetchUserDataCallback;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * SnapchatFlutterPlugin
 */
public class SnapchatFlutterPlugin implements MethodCallHandler, LoginStateController.OnLoginStateChangedListener {
    private Activity _activity;
    private MethodChannel.Result _result;

    public SnapchatFlutterPlugin(Activity activity) {
        this._activity = activity;
    }

    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "snapchat_flutter_plugin");
        channel.setMethodCallHandler(new SnapchatFlutterPlugin(registrar.activity()));
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("snap_chat_login")) {
            SnapLogin.getAuthTokenManager(_activity).startTokenGrant();
            SnapLogin.getLoginStateController(_activity).addOnLoginStateChangedListener(this);
            this._result = result;
        } else if (call.method.equals("snap_chat_logout")) {
            SnapLogin.getAuthTokenManager(_activity).revokeToken();
            SnapLogin.getLoginStateController(_activity).removeOnLoginStateChangedListener(this);
            this._result = result;
        } else {
            result.notImplemented();
        }
    }

    public void fetchUserData() {
        String query = "{me{bitmoji{avatar},displayName,externalId}}";
        SnapLogin.fetchUserData(_activity, query, null, new FetchUserDataCallback() {
            @Override
            public void onSuccess(@Nullable UserDataResponse userDataResponse) {
                if (userDataResponse == null || userDataResponse.getData() == null) {
                    return;
                }

                MeData meData = userDataResponse.getData().getMe();
                if (meData == null) {
                    _result.success("failed login");
                    return;
                }
                _result.success(meData);

            }

            @Override
            public void onFailure(boolean isNetworkError, int statusCode) {
                _result.success("failed login");
            }
        });
    }

    @Override
    public void onLoginSucceeded() {
        fetchUserData();
    }

    @Override
    public void onLoginFailed() {
    }

    @Override
    public void onLogout() {
        _result.success("logout");
    }
}

==> snapchat_flutter_plugin-0.0.3%2B1.tar.gz: android/src/main/java/com/proflutterdev/snapchat_flutter_plugin/SnapchatFlutterPlugin.java <==
package com.proflutterdev.snapchat_flutter_plugin;

import android.app.Activity;
import android.text.TextUtils;

import com.snapchat.kit.sdk.SnapLogin;
import com.snapchat.kit.sdk.core.controller.LoginStateController;
import com.snapchat.kit.sdk.login.models.MeData;
import com.snapchat.kit.sdk.login.models.UserDataResponse;
import com.snapchat.kit.sdk.login.networking.FetchUserDataCallback;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * SnapchatFlutterPlugin
 */
public class SnapchatFlutterPlugin implements MethodCallHandler,
        LoginStateController.OnLoginStateChangedListener {
    private Activity _activity;
    private MethodChannel.Result _result;

    public SnapchatFlutterPlugin(Activity activity) {
        this._activity = activity;
    }

    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "snapchat_flutter_plugin");
        channel.setMethodCallHandler(new SnapchatFlutterPlugin(registrar.activity()));
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("snap_chat_login")) {
            SnapLogin.getLoginStateController(_activity).addOnLoginStateChangedListener(this);
            SnapLogin.getAuthTokenManager(_activity).startTokenGrant();
            this._result = result;
        } else if (call.method.equals("snap_chat_logout")) {
            SnapLogin.getLoginStateController(_activity).removeOnLoginStateChangedListener(this);
            SnapLogin.getAuthTokenManager(_activity).revokeToken();
            this._result = result;
        } else {
            result.notImplemented();
        }
    }

    public void fetchUserData() {
        String query = "{me{bitmoji{avatar},displayName,externalId}}";
        SnapLogin.fetchUserData(_activity, query, null, new FetchUserDataCallback() {
            @Override
            public void onSuccess(UserDataResponse userDataResponse) {
                if (userDataResponse == null || userDataResponse.getData() == null) {
                    return;
                }

                MeData meData = userDataResponse.getData().getMe();
                if (meData == null) {
                    _result.error("400", "Error in login", null);
                    return;
                }
                Map<String, Object> data = new HashMap<String, Object>();
                data.put("fullName", meData.getDisplayName());
                data.put("_id", meData.getExternalId());
                if (meData.getBitmojiData() != null) {
                    if (!TextUtils.isEmpty(meData.getBitmojiData().getAvatar())) {
                        data.put("avatar", meData.getBitmojiData().getAvatar());
                    }
                }
                _result.success(data);

            }

            @Override
            public void onFailure(boolean isNetworkError, int statusCode) {
                _result.error("400", "Error in login", null);
            }
        });
    }

    @Override
    public void onLoginSucceeded() {
        fetchUserData();
    }

    @Override
    public void onLoginFailed() {
    }

    @Override
    public void onLogout() {
        _result.success("logout");
    }

}
